==> labdsv_1.0-1.tar.gz: labdsv/R/pco.R <==
pco <- function(dis, k=2)
{
    tmp <-cmdscale(dis,k=k,eig=TRUE)
    class(tmp) <- "pco"
    return(tmp)
}

plot.pco <- function(x, ax = 1, ay = 2, col = 1, title = "", pch = 1, ...)
{
    if(missing(x)) {
        stop("You must specify an object of class pco from pco()")
    }
    oldpin <- par("pin")
    par(pin=c(min(oldpin[1],oldpin[2]),min(oldpin[1],oldpin[2])))
    xlim <- range(x$points[,ax])
    ylim <- range(x$points[,ay])    
    tol <- 0.04
        midx <- 0.5 * (xlim[2] + xlim[1])
        midy <- 0.5 * (ylim[2] + ylim[1])
    if (xlim[2]-xlim[1] > ylim[2]-ylim[1]) {
        xlim <- midx + (1 + tol) * 0.5 * c(-1, 1) * (xlim[2] - xlim[1])
        ylim <- midy + (1 + tol) * 0.5 * c(-1, 1) * (xlim[2] - xlim[1])
    }
    else {
        xlim <- midx + (1 + tol) * 0.5 * c(-1, 1) * (ylim[2] - ylim[1])
        ylim <- midy + (1 + tol) * 0.5 * c(-1, 1) * (ylim[2] - ylim[1])
    }
    plot(x$points[, ax], x$points[, ay], xlim = xlim, ylim = ylim, 
        col = col, xlab = paste("PCO", ax), ylab = paste("PCO", ay),
        pch = pch, main = title, ...)
    par(pin=oldpin)
    invisible()
}


points.pco <- function(x, which, ax = 1, ay = 2, col = 2,  pch = 1, cex=1, ...)
{
    if(missing(x)) {
        stop("You must specify an object of class pco from pco()") 
    }
    if(missing(which)) {
        stop("You must specify a logical subscript")
    }
    points(x$points[, ax][which], x$points[, ay][which],col=col,pch=pch,cex=cex, ...) 
}

plotid.pco <- function(ord, ids=seq(1:nrow(ord$points)), ax = 1, ay = 2, col = 1, ...)
{
    if(missing(ord)) {
        stop("You must specify a list object from princomp()")
    }
    identify(ord$points[, ax],ord$points[, ay],ids)
}

surf.pco <- function(ord, var, ax=1, ay=2, col=2, labcex=0.8, family=gaussian, ...) 
{
    if (is.null(class(ord))) {
        stop("You must supply an object of class pco from pco()")
    }
    else if(class(ord) != "pco") {
        stop("You must specify a pco object from pco()")
    }
    if(missing(var)) {
        stop("You must specify a variable to surface")
    }
    x <- ord$points[,ax]
    y <- ord$points[,ay]
    if (any(is.na(var))) {
        cat("Omitting plots with missing values \n")
        x <- x[!is.na(var)]
        y <- y[!is.na(var)]
        var <- var[!is.na(var)]
    }
    if (is.logical(var)) {
        tmp <- gam(var~s(x)+s(y),family=binomial)
    } else {
        tmp <- gam(var~s(x)+s(y),family=family)
    }
    contour(interp(x,y,fitted(tmp)),add=TRUE,col=col,labcex=labcex, ...)
    print(tmp)
    d2  <- (tmp$null.deviance-tmp$deviance)/tmp$null.deviance
    cat(paste("D^2 = ",formatC(d2,width=4),"\n"))
}

jsurf.pco <- function(ord, var, ax=1, ay=2, col=2, labcex=0.8, family=gaussian, ...)
{
    if (is.null(class(ord))) {
        stop("You must supply an object of class pco from pco()")
    }
    else if(class(ord) != "pco") {
        stop("You must specify a pco object from pco()")
    }
    if(missing(var)) {
        stop("You must specify a variable to surface")
    }
    x <- ord$points[,ax]
    y <- ord$points[,ay]
    if (any(is.na(var))) {
        cat("Omitting plots with missing values \n")
        x <- x[!is.na(var)]
        y <- y[!is.na(var)]
        var <- var[!is.na(var)]
    }
    if (is.logical(var)) {
        tmp <- gam(var~s(x)+s(y),family=binomial)
    } else {
        tmp <- gam(var~s(x)+s(y),family=family)
    }
    contour(interp(jitter(x),jitter(y),fitted(tmp)),add=TRUE,col=col,labcex=labcex, ...)
    print(tmp)
    d2  <- (tmp$null.deviance-tmp$deviance)/tmp$null.deviance
    cat(paste("D^2 = ",formatC(d2,width=4),"\n"))
}

hilight.pco <- function (ord, factor, ax=1, ay=2, ...)
{
    if (is.null(class(ord)))
       stop("You must pass an object of class pco")
    if (!is.null(class(factor))) {
        if (class(factor) == 'partana' ||
            class(factor) == 'pam' ||
            class(factor) == 'slice')  factor <- factor$clustering
    }
    else if (is.logical(factor)) {
        factor <- as.numeric(factor)
    }
    col <- 1
    pch <- 1
    for (i in 1:max(factor)) {
        if (i >= 8)
            points(ord, factor == i, ax, ay, col = 8, pch = 1)
        points(ord, factor == i, ax, ay, col = col, pch = pch)
        col <- col + 1
        if (col == 8) {
            col <- 1
            pch <- pch + 2
        }
    }
}

==> labdsv_1.2-1.tar.gz: labdsv/R/pco.R <==
pco <- function(dis, k=2)
{
    tmp <-cmdscale(dis,k=k,eig=TRUE)
    class(tmp) <- "pco"
    return(tmp)
}

plot.pco <- function(x, ax = 1, ay = 2, col = 1, title = "", pch = 1, ...)
{
    if(missing(x)) {
        stop("You must specify an object of class pco from pco()")
    }
    oldpin <- par("pin")
    par(pin=c(min(oldpin[1],oldpin[2]),min(oldpin[1],oldpin[2])))
    xlim <- range(x$points[,ax])
    ylim <- range(x$points[,ay])    
    tol <- 0.04
        midx <- 0.5 * (xlim[2] + xlim[1])
        midy <- 0.5 * (ylim[2] + ylim[1])
    if (xlim[2]-xlim[1] > ylim[2]-ylim[1]) {
        xlim <- midx + (1 + tol) * 0.5 * c(-1, 1) * (xlim[2] - xlim[1])
        ylim <- midy + (1 + tol) * 0.5 * c(-1, 1) * (xlim[2] - xlim[1])
    }
    else {
        xlim <- midx + (1 + tol) * 0.5 * c(-1, 1) * (ylim[2] - ylim[1])
        ylim <- midy + (1 + tol) * 0.5 * c(-1, 1) * (ylim[2] - ylim[1])
    }
    plot(x$points[, ax], x$points[, ay], xlim = xlim, ylim = ylim, 
        col = col, xlab = paste("PCO", ax), ylab = paste("PCO", ay),
        pch = pch, main = title, ...)
    par(pin=oldpin)
    invisible()
}


points.pco <- function(x, which, ax = 1, ay = 2, col = 2,  pch = 1, cex=1, ...)
{
    if(missing(x)) {
        stop("You must specify an object of class pco from pco()") 
    }
    if(missing(which)) {
        stop("You must specify a logical subscript")
    }
    points(x$points[, ax][which], x$points[, ay][which],col=col,pch=pch,cex=cex, ...) 
}

plotid.pco <- function(ord, ids=seq(1:nrow(ord$points)), ax = 1, ay = 2, col = 1, ...)
{
    if(missing(ord)) {
        stop("You must specify a list object from princomp()")
    }
    identify(ord$points[, ax],ord$points[, ay],ids)
}

surf.pco <- function(ord, var, ax=1, ay=2, col=2, labcex=0.8, family=gaussian, ...) 
{
    if (class(ord) != 'pco')
        stop("You must supply an object of class pco from pco()")
    if (missing(var)) {
        stop("You must specify a variable to surface")
    }
    x <- ord$points[,ax]
    y <- ord$points[,ay]
    if (any(is.na(var))) {
        cat("Omitting plots with missing values \n")
        x <- x[!is.na(var)]
        y <- y[!is.na(var)]
        var <- var[!is.na(var)]
    }
    if (is.logical(var)) {
        tmp <- gam(var~s(x)+s(y),family=binomial)
    } else {
        tmp <- gam(var~s(x)+s(y),family=family)
    }
    contour(interp(x,y,fitted(tmp)),add=TRUE,col=col,labcex=labcex, ...)
    print(tmp)
    d2  <- (tmp$null.deviance-tmp$deviance)/tmp$null.deviance
    cat(paste("D^2 = ",formatC(d2,width=4),"\n"))
}

jsurf.pco <- function(ord, var, ax=1, ay=2, col=2, labcex=0.8, family=gaussian, ...)
{
    if (class(ord) != 'pco')
        stop("You must supply an object of class pco from pco()")
    if (missing(var)) {
        stop("You must specify a variable to surface")
    }
    x <- ord$points[,ax]
    y <- ord$points[,ay]
    if (any(is.na(var))) {
        cat("Omitting plots with missing values \n")
        x <- x[!is.na(var)]
        y <- y[!is.na(var)]
        var <- var[!is.na(var)]
    }
    if (is.logical(var)) {
        tmp <- gam(var~s(x)+s(y),family=binomial)
    } else {
        tmp <- gam(var~s(x)+s(y),family=family)
    }
    contour(interp(jitter(x),jitter(y),fitted(tmp)),add=TRUE,col=col,labcex=labcex, ...)
    print(tmp)
    d2  <- (tmp$null.deviance-tmp$deviance)/tmp$null.deviance
    cat(paste("D^2 = ",formatC(d2,width=4),"\n"))
}

hilight.pco <- function (ord, overlay, ax=1, ay=2, cols=c(2,3,4,5,6,7), glyph=c(1,3,5), origpch=1, blank='#FFFFFF', ...)
{
    if (class(ord) != 'pco')
       stop("You must pass an object of class pco")
    if (inherits(overlay,c('partana','pam','slice')))
       overlay <- overlay$clustering
    if (is.logical(overlay) || is.factor(overlay))
        overlay <- as.numeric(overlay)
    layer <- 0
    pass <- 1
    for (i in 1:max(overlay,na.rm=TRUE)) {
        points(ord, overlay == i, ax, ay, col = blank, pch = origpch)
        layer <- layer + 1
        if (layer > length(cols)) {
          layer <- 1
          pass <- pass + 1
        }
        col <- cols[layer]
        pch <- glyph[pass]
        points(ord, overlay == i, ax, ay, col = col, pch = pch)
    }
}

chullord.pco <- function (ord, overlay, ax = 1, ay = 2, cols=c(2,3,4,5,6,7), ltys=c(1,2,3), ...)
{
    if (class(ord) != 'pco')
        stop("You must pass an object of class pco")
    if (inherits(overlay,c('partana','pam','slice')))
       overlay <- overlay$clustering
    else if (is.logical(overlay))
        overlay <- as.numeric(overlay)
    else if (is.factor(overlay))
        overlay <- as.numeric(overlay)
    pass <- 1
    layer <- 0
    lty <- ltys[pass]
    for (i in 1:max(overlay,na.rm=TRUE)) {
        x <- ord$points[,ax][overlay==i & !is.na(overlay)]
        y <- ord$points[,ay][overlay==i & !is.na(overlay)]
        pts <- chull(x,y)
        layer <- layer + 1
        if (layer > length(cols)) {
          layer <- 1
          pass <- min(pass + 1,length(ltys))
        }
        col <- cols[layer]
        lty = ltys[pass]
        polygon(x[pts],y[pts],col=col,density=0,lty=lty)
    }
}
